@@ -25,7 +25,7 @@
  *    Christian Gmeiner <christian.gmeiner@gmail.com>
  */
 
-#include "os/os_time.h"
+#include "util/os_time.h"
 #include "pipe/p_state.h"
 #include "util/u_memory.h"
 #include "util/u_string.h"
